@@ -315,9 +315,10 @@ fact2num <- function(object) {
 
 #' @title Opens web pages associated with the fishR website.
 #'
-#' @description Opens web pages associated with the \href{http://derekogle.com/fishR/}{fishR website} in a browser. The user can open the main page or choose a specific page to open.
+#' @description Opens web pages associated with the \href{https://derekogle.com/fishR/}{fishR website} in a browser. The user can open the main page or choose a specific page to open.
 #'
 #' @param where A string that indicates a particular page on the fishR website to open.
+#' @param open A logical that indicates whether the webpage should be opened in the default browser. Defaults to \code{TRUE}; \code{FALSE} is used for unit testing.
 #' 
 #' @return None, but a webpage will be opened in the default browser.
 #' 
@@ -338,9 +339,10 @@ fact2num <- function(object) {
 #' 
 #' @export
 fishR <- function(where=c("home","IFAR","general","books",
-                          "AIFFD","posts","news")) {
+                          "AIFFD","posts","news"),
+                  open=TRUE) {
   where <- match.arg(where)
-  tmp <- "http://derekogle.com/"
+  tmp <- "https://derekogle.com/"
   switch(where,
          home=   { tmp <- paste0(tmp,"fishR") },
          IFAR=   { tmp <- paste0(tmp,"IFAR") },
@@ -349,7 +351,7 @@ fishR <- function(where=c("home","IFAR","general","books",
          AIFFD=  { tmp <- paste0(tmp,"aiffd2007") },
          posts=,news=  { tmp <- paste0(tmp,"fishR/blog") }
   )
-  utils::browseURL(tmp)
+  if (open) utils::browseURL(tmp)
   invisible(tmp)
 }
 
@@ -1045,9 +1047,9 @@ se <- function (x,na.rm=TRUE) {
 #'
 #' @description Subsets/filters a data frame and drops the unused levels.
 #'
-#' @details Newbie students using R expect that when a factor variable is subsetted with \code{\link{subset}} or filtered with \code{\link[dplyr]{filter}} that any original levels that are no longer used after the subsetting or filtering will be ignored. This, however, is not the case and often results in tables with empty cells and figures with empty bars. One remedy is to use \code{\link[gdata]{drop.levels}} from \pkg{gdata} immediately following the \code{\link{subset}} or \code{\link[dplyr]{filter}} call. This generally becomes a repetitive sequence for most newbie students; thus, \code{Subset} and \code{filterD} incorporate these two functions into one function.
+#' @details Newbie students using R expect that when a factor variable is subsetted with \code{\link{subset}} or filtered with \code{\link[dplyr]{filter}} that any original levels that are no longer used after the subsetting or filtering will be ignored. This, however, is not the case and often results in tables with empty cells and figures with empty bars. One remedy is to use \code{drop.levels} from \pkg{gdata} immediately following the \code{\link{subset}} or \code{\link[dplyr]{filter}} call. This generally becomes a repetitive sequence for most newbie students; thus, \code{Subset} and \code{filterD} incorporate these two functions into one function.
 #' 
-#' \code{Subset} is a wrapper to \code{\link{subset}} with a catch for non-data.frames and a specific call to \code{\link[gdata]{drop.levels}} just before the data.frame is returned. I also added an argument to allow resetting the row names. \code{filterD} is a wrapper for \code{\link[dplyr]{filter}} from \pkg{dplyr} followed by \code{\link[gdata]{drop.levels}} just before the data.frame is returned. Otherwise, there is no new code here.
+#' \code{Subset} is a wrapper to \code{\link{subset}} with a catch for non-data.frames and a specific call to \code{drop.levels} just before the data.frame is returned. I also added an argument to allow resetting the row names. \code{filterD} is a wrapper for \code{\link[dplyr]{filter}} from \pkg{dplyr} followed by \code{drop.levels} just before the data.frame is returned. Otherwise, there is no new code here.
 #' 
 #' These functions are used only for data frames.
 #' 
@@ -1065,7 +1067,7 @@ se <- function (x,na.rm=TRUE) {
 #' 
 #' @section IFAR Chapter: Basic Data Manipulations.
 #'
-#' @seealso See \code{subset} and \code{\link[dplyr]{filter}} from \pkg{dplyr} for similar functionality. See \code{\link[gdata]{drop.levels}} in \pkg{gdata} and \code{\link{droplevels}} for related functionality.
+#' @seealso See \code{subset} and \code{\link[dplyr]{filter}} from \pkg{dplyr} for similar functionality. See \code{drop.levels} in \pkg{gdata} and \code{droplevels} for related functionality.
 #'
 #' @keywords misc
 #'
@@ -1134,7 +1136,7 @@ filterD <- function(x,...,except=NULL) {
 #'
 #' @return A single numeric value that is the number of non-\code{NA} values in a vector.
 #' 
-#' @seealso See \code{\link[plotrix]{valid.n}} in \pkg{plotrix} and \code{\link[gdata]{nobs}} in \pkg{gdata} for similar functionality. See \code{\link{is.na}} for finding the missing values.
+#' @seealso See \code{\link[plotrix]{valid.n}} in \pkg{plotrix} and \code{nobs} in \pkg{gdata} for similar functionality. See \code{\link{is.na}} for finding the missing values.
 #' 
 #' @author Derek H. Ogle, \email{derek@@derekogle.com}
 #'
